==> nocc-1.7.tar.gz: lang/de.php <==
<?php
/*
 * $Header: /cvsroot/nocc/nocc/webmail/lang/de.php,v 1.68 2008/07/27 07:53:23 goddess_skuld Exp $ 
 *
 * Copyright 2000 Nicolas Chalanset <nicocha AT free DOT fr>
 * Copyright 2000 Olivier Cahagne <wolruf AT free DOT fr>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * Configuration file for the german language
 * Translation by
 * 	David Ferch <dferch AT tk-online DOT net>
 *	Benjamin Bräuer <ben1 AT gmx DOT de>
 *	Alexander Schremmer <alex AT alexanderweb DOT de>
 *	Tim Gerundt <tim AT gerundt DOT de>
 */

$charset = 'UTF-8';

// Configuration for the days and months

// What language to use
// see '/usr/share/locale/' for more information
$lang_locale = 'de_DE.UTF-8';

// Text Alignment
// Can be right-to-left (rtl) which is needed for proper Arabic, Hebrew
// Or left-to-right (ltr) which is default for most languages
$lang_dir = 'ltr';

// What format string should we pass to strftime() for messages sent on
// days other than today?
$default_date_format = '%d.%m.%Y'; 

// If the local is not implemented on the host, how we display the date
$no_locale_date_format = '%d.%m.%Y';

// What format string should we pass to strftime() for messages sent
// today?
$default_time_format = '%H:%M';


// Here is the configuration for the HTML

$err_user_empty = 'Kein Nutzername eingegeben';
$err_passwd_empty = 'Kein Passwort eingegeben';


// html message

$alt_delete = 'Markierte Nachrichten löschen';
$alt_delete_one = 'Nachricht löschen';
$alt_new_msg = 'Neue Nachrichten';
$alt_reply = 'Antwort an Absender';
$alt_reply_all = 'Antwort an alle';
$alt_forward = 'Weiterleitung';
$alt_next = 'Nächste';
$alt_prev = 'Vorige';
$title_next_page = 'Nächste Seite';
$title_prev_page = 'Vorige Seite';
$title_next_msg = 'Nächste Nachricht';
$title_prev_msg = 'Vorige Nachricht';
$html_on = 'an';
$html_theme = 'Theme';

// index.php

$html_lang = 'Sprache';
$html_welcome = 'Willkommen bei';
$html_login = 'Login';
$html_passwd = 'Passwort';
$html_submit = 'Ok';
$html_help = 'Hilfe';
$html_server = 'Server';
$html_wrong = 'Der Nutzername oder das Passwort sind falsch';
$html_retry = 'Nochmal';
$html_remember = "Einstellungen speichern";

// prefs.php

$html_msgperpage = 'Nachrichten pro Seite';
$html_preferences = 'Einstellungen';
$html_full_name = 'Vollständiger Name';
$html_email_address = 'E-Mail-Adresse';
$html_ccself = 'Kopie der gesendeten Nachrichten an die eigene Adresse schicken';
$html_hide_addresses = 'Adressen verstecken';
$html_outlook_quoting = 'Quoting im Outlook-Stil';
$html_reply_to = 'Antwort an';
$html_use_signature = 'Signatur benutzen';
$html_signature = 'Signatur';
$html_reply_leadin = 'Antwort-Einleitung';
$html_prefs_updated = 'Einstellungen gespeichert';
$html_manage_folders_link = 'IMAP-Ordner verwalten';
$html_manage_filters_link = 'E-Mail-Filter verwalten';
$html_use_graphical_smilies = 'Benutze graphische Emoticons';
$html_sent_folder = 'Kopiere gesendete E-Mail in das angegebene Verzeichnis';
$html_trash_folder = 'Move deleted mails into a dedicated folder'; // to translate
$html_colored_quotes = 'Farbige Zitate';
$html_display_struct = 'Strukturierten Text anzeigen';
$html_send_html_mail = 'E-Mail im HTML-Format versenden';

// folders.php
$html_folders = 'Ordner';
$html_folders_create_failed = 'Der Ordner konnte nicht angelegt werden!';
$html_folders_sub_failed = 'Der Ordner konnte nicht abonniert werden!';
$html_folders_unsub_failed = 'Der Ordner konnte nicht abbestellt werden!';
$html_folders_rename_failed = 'Der Ordner konnte nicht umbenannt werden!';
$html_folders_updated = 'Die Ordner wurden aktualisiert';
$html_folder_subscribe = 'Abonniere';
$html_folder_rename = 'Umbenennen:';
$html_folder_create = 'Erstelle neuen Ordner';
$html_folder_remove = 'Abbestellen:';
$html_folder_delete = 'Lösche';
$html_folder_to = 'nach';

// filters.php
$html_filter_remove = 'Löschen';
$html_filter_body = 'Nachrichtentext';
$html_filter_subject = 'Betreff';
$html_filter_to = 'Empfängerfeld (To)';
$html_filter_cc = 'Cc-Feld';
$html_filter_from = 'Absenderfeld (From)';
$html_filter_change_tip = 'Um einen Filter zu ändern, können Sie diesen einfach überschreiben.';
$html_reapply_filters = 'Alle Filter erneut anwenden';
$html_filter_contains = 'enthält';
$html_filter_name = 'Filter Name';
$html_filter_action = 'Filter Aktion';
$html_filter_moveto = 'Verschiebe nach';

// Other pages
$html_select_one = '--Auswählen--';
$html_and = 'Und';
$html_new_msg_in = 'Neue Nachrichten in';
$html_or = 'oder';
$html_move = 'Verschiebe';
$html_copy = 'Kopiere';
$html_messages_to = 'die markierten Nachrichten nach';
$html_gotopage = 'Gehe zu Seite';
$html_gotofolder = 'Gehe zu Ordner';
$html_other_folders = 'Ordner Liste';
$html_page = 'Seite';
$html_of = 'von';
$html_view_header = 'Header anzeigen';
$html_remove_header = 'Header verbergen';
$html_inbox = 'Posteingang';
$html_new_msg = 'Schreiben';
$html_reply = 'Antworten';
$html_reply_short = 'Re';
$html_reply_all = 'Antwort an alle';
$html_forward = 'Weiterleitung';
$html_forward_short = 'Fw';
$html_forward_info = 'Die weiterzuleitende Nachricht wird als Anhang mit dieser E-Mail verschickt.';
$html_delete = 'Löschen';
$html_new = 'Neu';
$html_mark = 'Löschen';
$html_att = 'Anhang';
$html_atts = 'Anhänge';
$html_att_unknown = '[unbekannt]';
$html_attach = 'Anhängen';
$html_attach_forget = 'Sie müssen die Datei vor dem Senden der Nachricht anhängen !';
$html_attach_delete = 'Ausgewählte entfernen';
$html_attach_none = 'Als Anhang müssen Sie eine Datei auswählen!';
$html_sort_by = 'Sortieren nach';
$html_sort = 'Sortieren';
$html_from = 'Von';
$html_subject = 'Betreff';
$html_date = 'Datum';
$html_sent = 'Gesendet';
$html_wrote = 'schrieb';
$html_size = 'Grösse';
$html_totalsize = 'Gesamtgrösse';
$html_kb = 'KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Byte';
$html_filename = 'Datei';
$html_to = 'An';
$html_cc = 'Kopie';
$html_bcc = 'Blindkopie';
$html_nosubject = 'Kein Betreff';
$html_send = 'Senden';
$html_cancel = 'Abbrechen';
$html_no_mail = 'Keine neue Nachrichten.';
$html_logout = 'Abmelden';
$html_msg = 'Nachricht';
$html_msgs = 'Nachrichten';
$html_configuration = 'Dieser Server ist nicht richtig konfiguriert!';
$html_priority = 'Priorität';
$html_low = 'Niedrig';
$html_normal = 'Normal';
$html_high = 'Hoch';
$html_receipt = 'Lesebestätigung anfordern';
$html_select = 'Auswahl';
$html_select_all = 'Invertiere Auswahl';
$html_loading_image = 'Lade Bild';
$html_send_confirmed = 'Ihre Mail wurde verschickt.';
$html_no_sendaction = 'Keine Aktion angegeben. Versuchen Sie es mit eingeschaltetem JavaScript.';
$html_error_occurred = 'Ein Fehler ist aufgetreten';
$html_prefs_file_error = 'Kann Ihre Einstellungen-Datei nicht zum Schreiben öffnen.';
$html_wrap = 'Umbrechen der ausgehenden Nachrichten nach x Zeichen:';
$html_wrap_none = 'Keine';
$html_usenet_separator = 'Usenet-Signaturtrenner ("-- \n") benutzen';
$html_mark_as = 'Markiere als';
$html_read = 'gelesen';
$html_unread = 'ungelesen';
$html_encoding = 'Zeichensatz-Kodierung';

// Contacts manager
$html_add = 'Hinzufügen';
$html_contacts = 'Kontakte';
$html_modify = 'Ändere';
$html_back = 'Zurück';
$html_contact_add = 'Füge neuen Kontakt hinzu';
$html_contact_mod = 'Ändere einen Kontakt';
$html_contact_first = 'Vorname';
$html_contact_last = 'Nachname';
$html_contact_nick = 'Spitzname';
$html_contact_mail = 'E-Mail-Adresse';
$html_contact_list = 'Kontaktliste von ';
$html_contact_del = 'von der Kontaktliste';

$html_contact_err1 = 'Die Maximalanzahl der Kontakte ist ';
$html_contact_err2 = 'Sie können keinen neuen Kontakt hinzufügen';
$html_contact_err3 = 'Sie haben keine Rechte, um auf die Kontaktliste zuzugreifen';
$html_del_msg = 'Sollen die markierten Nachrichten gelöscht werden?';
$html_down_mail = 'Download';

$original_msg = '-- Original Nachricht--';
$to_empty = 'Das \'An\' Feld darf nicht leer sein !';

// Images warning
$html_images_warning = 'Zu Ihrer Sicherheit werden externe Bilder nicht angezeigt.';
$html_images_display = 'Bilder anzeigen';

// SMTP problems (class_smtp.php)
$html_smtp_error_no_conn = 'Konnte Verbindung nicht öffnen';
$html_smtp_error_unexpected = 'Unerwartete Antwort:';

// IMAP messages (class_local.php)
$lang_could_not_connect = 'Verbindung zum Server fehlgeschlagen';
$lang_invalid_msg_num = 'Fehlerhafte Nachrichten-Nummer';

$html_file_upload_attack = 'Die hochgeladene Datei konnte nicht gefunden werden.';
$html_invalid_email_address = 'Ungültige E-Mail-Adresse';
$html_invalid_msg_per_page = 'Ungültige Anzahl von Nachrichten pro Seite.';
$html_invalid_wrap_msg = 'Ungültiger Nachrichtenumbruch';
$html_seperate_msg_win = 'Nachricht in neuem Fenster öffnen';

// Exceptions
$html_err_file_contacts = 'Kann die Kontaktdatei nicht zum Schreiben öffnen.';
$html_session_file_error = 'Kann die Sitzungsdatei nicht zum Schreiben öffnen.';
$html_login_not_allowed = 'Diese Anmeldung ist nicht für die Verbindung zugelassen.';

// Send delay
$lang_err_send_delay = 'You must wait between two mails'; // to translate
$lang_seconds = 'seconds'; // to translate
?>

==> nocc-1.8.2.tar.gz: lang/de.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: de.php 2044 2009-10-31 14:41:24Z gerundt $
 */

/** German (Deutsch)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Alexander Schremmer <alex AT alexanderweb DOT de>
 * @author Als-Holder
 * @author Benjamin Bräuer <ben1 AT gmx DOT de>
 * @author David Ferch <dferch AT tk-online DOT net>
 * @author Purodha
 * @author Tim Gerundt <tim AT gerundt DOT de>
 * @author Twobee
 * @author Umherirrender
 * @author Xqt
 */

$lang_locale = 'de_DE.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Kein Nutzername eingegeben';
$err_passwd_empty = 'Kein Passwort eingegeben';
$alt_delete = 'Markierte Nachrichten löschen';
$alt_delete_one = 'Nachricht löschen';
$alt_new_msg = 'Neue Nachrichten';
$alt_reply = 'Antwort an Absender';
$alt_reply_all = 'Antwort an alle';
$alt_forward = 'Weiterleitung';
$alt_next = 'Nächste';
$alt_prev = 'Vorherige';
$title_next_page = 'Nächste Seite';
$title_prev_page = 'Vorherige Seite';
$title_next_msg = 'Nächste Nachricht';
$title_prev_msg = 'Vorherige Nachricht';
$html_theme_label = 'Thema:';
$html_welcome = 'Willkommen bei %1$s';
$html_login = 'Anmelden';
$html_user_label = 'Benutzer:';
$html_passwd_label = 'Passwort:';
$html_submit = 'Ok';
$html_help = 'Hilfe';
$html_server_label = 'Server:';
$html_wrong = 'Der Nutzername oder das Passwort sind falsch';
$html_retry = 'Nochmal';
$html_remember = 'Einstellungen speichern';
$html_lang_label = 'Sprache:';
$html_msgperpage_label = 'Nachrichten pro Seite:';
$html_preferences = 'Einstellungen';
$html_full_name_label = 'Vollständiger Name:';
$html_email_address_label = 'E-Mail-Adresse:';
$html_ccself = 'Kopie der gesendeten Nachrichten an die eigene Adresse schicken';
$html_hide_addresses = 'Adressen verstecken';
$html_outlook_quoting = 'Aus Originalnachrichten im Outlook-Stil zitieren';
$html_reply_to = 'Antwort an';
$html_use_signature = 'Signatur benutzen';
$html_signature = 'Signatur';
$html_signature_label = 'Signatur:';
$html_reply_leadin_label = 'Antwort-Einleitung:';
$html_prefs_updated = 'Einstellungen gespeichert';
$html_manage_folders_link = 'IMAP-Ordner verwalten';
$html_manage_filters_link = 'E-Mail-Filter verwalten';
$html_use_graphical_smilies = 'Benutze graphische Emoticons';
$html_sent_folder_label = 'Gesendete E-Mail in den nachfolgenden Ordner kopieren:';
$html_trash_folder_label = 'Gelöschte E-Mails in den nachfolgenden Ordner verschieben:';
$html_colored_quotes = 'Farbige Zitate';
$html_display_struct = 'Strukturierten Text anzeigen';
$html_send_html_mail = 'E-Mail im HTML-Format versenden';
$html_folders = 'Ordner';
$html_folders_create_failed = 'Der Ordner konnte nicht angelegt werden!';
$html_folders_sub_failed = 'Der Ordner konnte nicht abonniert werden!';
$html_folders_unsub_failed = 'Der Ordner konnte nicht abbestellt werden!';
$html_folders_rename_failed = 'Der Ordner konnte nicht umbenannt werden!';
$html_folders_updated = 'Die Ordner wurden aktualisiert';
$html_folder_subscribe = 'Abonniere';
$html_folder_rename = 'Umbenennen';
$html_folder_create = 'Erstelle neuen Ordner';
$html_folder_remove = 'Abbestellen:';
$html_folder_delete = 'Lösche';
$html_folder_to = 'nach';
$html_filter_remove = 'Löschen';
$html_filter_body = 'Nachrichtentext';
$html_filter_subject = 'Betreff';
$html_filter_to = 'Empfängerfeld (To)';
$html_filter_cc = 'Cc-Feld';
$html_filter_from = 'Absenderfeld (From)';
$html_filter_change_tip = 'Um einen Filter zu ändern, können Sie diesen einfach überschreiben.';
$html_reapply_filters = 'Alle Filter erneut anwenden';
$html_filter_contains = 'enthält';
$html_filter_name = 'Filter Name';
$html_filter_action = 'Filter Aktion';
$html_filter_moveto = 'Verschiebe nach';
$html_select_one = '--Auswählen--';
$html_and = 'Und';
$html_new_msg_in = 'Neue Nachrichten in';
$html_or = 'oder';
$html_move = 'Verschiebe';
$html_copy = 'Kopiere';
$html_messages_to = 'die markierten Nachrichten nach';
$html_gotopage = 'Gehe zu Seite';
$html_gotofolder = 'Gehe zu Ordner';
$html_other_folders = 'Ordner Liste';
$html_page = 'Seite';
$html_of = 'von';
$html_view_header = 'Header anzeigen';
$html_remove_header = 'Header verbergen';
$html_inbox = 'Posteingang';
$html_new_msg = 'Schreiben';
$html_reply = 'Antworten';
$html_reply_short = 'Re:';
$html_reply_all = 'Antwort an alle';
$html_forward = 'Weiterleitung';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Die weiterzuleitende Nachricht wird als Anhang mit dieser E-Mail verschickt.';
$html_delete = 'Löschen';
$html_new = 'Neu';
$html_mark = 'Löschen';
$html_att_label = 'Anhang:';
$html_atts_label_label = 'Anhänge:';
$html_unknown = '[unbekannt]';
$html_attach = 'Anhängen';
$html_attach_forget = 'Sie müssen die Datei vor dem Senden der Nachricht anhängen!';
$html_attach_delete = 'Ausgewählte entfernen';
$html_attach_none = 'Als Anhang müssen Sie eine Datei auswählen!';
$html_sort_by = 'Sortieren nach';
$html_sort = 'Sortieren';
$html_from = 'Von';
$html_from_label = 'Von:';
$html_subject = 'Betreff';
$html_subject_label = 'Betreff:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent = 'Gesendet:';
$html_wrote = 'schrieb';
$html_size = 'Größe';
$html_totalsize = 'Gesamtgröße';
$html_kb = 'KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Byte';
$html_filename = 'Datei';
$html_to = 'An';
$html_to_label = 'An:';
$html_cc = 'Kopie';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Blindkopie:';
$html_nosubject = 'Kein Betreff';
$html_send = 'Senden';
$html_cancel = 'Abbrechen';
$html_no_mail = 'Keine neue Nachrichten.';
$html_logout = 'Abmelden';
$html_msg = 'Nachricht';
$html_msgs = 'Nachrichten';
$html_configuration = 'Dieser Server ist nicht richtig konfiguriert!';
$html_priority = 'Priorität';
$html_priority_label = 'Priorität:';
$html_lowest = 'Sehr niedrig';
$html_low = 'Niedrig';
$html_normal = 'Normal';
$html_high = 'Hoch';
$html_highest = 'Sehr hoch';
$html_flagged = 'Kennzeichnung';
$html_receipt = 'Lesebestätigung anfordern';
$html_select = 'Auswahl';
$html_select_all = 'Invertiere Auswahl';
$html_select_contacts = 'Kontakte auswählen';
$html_loading_image = 'Lade Bild';
$html_send_confirmed = 'Ihre Mail wurde verschickt.';
$html_no_sendaction = 'Keine Aktion angegeben. Versuchen Sie es mit eingeschaltetem JavaScript.';
$html_error_occurred = 'Ein Fehler ist aufgetreten';
$html_prefs_file_error = 'Kann Ihre Einstellungen-Datei nicht zum Schreiben öffnen.';
$html_wrap = 'Anzahl der Zeichen, nachdem ausgehende Nachrichten umgebrochen werden sollen:';
$html_wrap_none = 'Kein Umbruch';
$html_usenet_separator = 'Usenet-Signaturtrenner ("-- \n") benutzen';
$html_mark_as = 'Markiere als';
$html_read = 'gelesen';
$html_unread = 'ungelesen';
$html_encoding_label = 'Zeichensatz-Kodierung:';
$html_add = 'Hinzufügen';
$html_contacts = '%1$s Kontakte';
$html_modify = 'Ändere';
$html_back = 'Zurück';
$html_contact_add = 'Füge neuen Kontakt hinzu';
$html_contact_mod = 'Ändere einen Kontakt';
$html_contact_first = 'Vorname';
$html_contact_last = 'Nachname';
$html_contact_nick = 'Spitzname';
$html_contact_mail = 'E-Mail-Adresse';
$html_contact_list = 'Kontaktliste von %1$s';
$html_contact_del = 'von der Kontaktliste';
$html_contact_count = '%1$d Kontakte';
$html_contact_err1 = 'Die Maximalanzahl der Kontakte ist „%1$d“';
$html_contact_err2 = 'Sie können keinen neuen Kontakt hinzufügen';
$html_contact_err3 = 'Sie haben keine Rechte, um auf die Kontaktliste zuzugreifen';
$html_contact_none = 'Es konnten keine Kontakte gefunden werden.';
$html_del_msg = 'Sollen die markierten Nachrichten gelöscht werden?';
$html_down_mail = 'Download';
$original_msg = '-- Original Nachricht --';
$to_empty = 'Das „An“-Feld darf nicht leer sein!';
$html_images_warning = 'Zu Ihrer Sicherheit werden externe Bilder nicht angezeigt.';
$html_images_display = 'Bilder anzeigen';
$html_smtp_error_no_conn = 'Konnte keine smtp-Verbindung öffnen';
$html_smtp_error_unexpected = 'Unerwartete Antwort:';
$lang_could_not_connect = 'Verbindung zum Server fehlgeschlagen';
$lang_invalid_msg_num = 'Fehlerhafte Nachrichten-Nummer';
$html_file_upload_attack = 'Die hochgeladene Datei konnte nicht gefunden werden.';
$html_invalid_email_address = 'Ungültige E-Mail-Adresse';
$html_invalid_msg_per_page = 'Ungültige Anzahl von Nachrichten pro Seite.';
$html_invalid_wrap_msg = 'Ungültiger Nachrichtenumbruch';
$html_seperate_msg_win = 'Nachrichten in neuem Fenster öffnen';
$html_err_file_contacts = 'Kann die Kontaktdatei nicht zum Schreiben öffnen.';
$html_session_file_error = 'Kann die Sitzungsdatei nicht zum Schreiben öffnen.';
$html_login_not_allowed = 'Diese Anmeldung ist nicht für die Verbindung zugelassen.';
$lang_err_send_delay = 'Bitte lassen Sie etwas Zeit zwischen dem Versenden zweier E-Mails vergehen (%1$d Sekunden)';
$html_search = 'Suchen';
